@@ -1,13 +1,13 @@
 //! This service requests the ECU to perform a reset
 
-use crate::DiagServerResult;
+use crate::{DiagServerResult, DiagnosticServer};
 
 use super::{KWP2000Command, Kwp2000DiagnosticServer};
 
 /// ECU Reset types
-/// 
+///
 /// Command support matrix
-/// 
+///
 /// | ResetMode | Support by ECUs |
 /// |--|--|
 /// |[ResetMode::PowerOnReset]|Mandatory|
@@ -20,7 +20,7 @@ pub enum ResetMode {
     /// Just resets Non volatile memory of the ECU, resetting it
     NonVolatileMemoryReset,
     /// Custom reset mode (Not defined by KWP2000 specification)
-    Custom(u8)
+    Custom(u8),
 }
 
 impl From<ResetMode> for u8 {
@@ -28,16 +28,21 @@ impl From<ResetMode> for u8 {
         match x {
             ResetMode::PowerOnReset => 0x01,
             ResetMode::NonVolatileMemoryReset => 0x82,
-            ResetMode::Custom(x) => x
+            ResetMode::Custom(x) => x,
         }
     }
 }
 
 /// Performs an ECU Reset operation
-/// 
+///
 /// ## Params
 /// * server - KWP2000 diagnostic server
 /// * mode - [ResetMode] to send to the ECU
-pub fn execute_reset(server: &mut Kwp2000DiagnosticServer, mode: ResetMode) -> DiagServerResult<()> {
-    server.execute_command(KWP2000Command::ECUReset, &[mode.into()]).map(|_| ())
-}
\ No newline at end of file
+pub fn execute_reset(
+    server: &mut Kwp2000DiagnosticServer,
+    mode: ResetMode,
+) -> DiagServerResult<()> {
+    server
+        .execute_command_with_response(KWP2000Command::ECUReset, &[mode.into()])
+        .map(|_| ())
+}
